==> rewrite-build-gradle-plugin-1.9.7-sources.jar: org/openrewrite/gradle/RewriteShadowPlugin.java <==
/*
 * Copyright 2022 the original author or authors.
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * https://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.openrewrite.gradle;

import com.github.jengelman.gradle.plugins.shadow.ShadowPlugin;
import com.github.jengelman.gradle.plugins.shadow.tasks.ShadowJar;
import org.gradle.api.Plugin;
import org.gradle.api.Project;
import org.gradle.api.plugins.JavaLibraryPlugin;
import org.gradle.jvm.tasks.Jar;

import static java.util.Collections.singletonList;

public class RewriteShadowPlugin implements Plugin<Project> {

    @Override
    public void apply(Project project) {
        project.getPlugins().apply(JavaLibraryPlugin.class);
        project.getPlugins().apply(ShadowPlugin.class);

        project.getTasks().named("jar", Jar.class, task ->
                task.setEnabled(false));

        project.getTasks().withType(ShadowJar.class, task -> {
            task.setConfigurations(singletonList(project.getConfigurations().getByName("compileClasspath")));
            task.getArchiveClassifier().set((String) null);
        });
    }
}

==> rewrite-build-gradle-plugin-1.127.1-sources.jar: org/openrewrite/gradle/RewriteShadowPlugin.java <==
/*
 * Copyright 2022 the original author or authors.
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * https://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.openrewrite.gradle;

import com.github.jengelman.gradle.plugins.shadow.ShadowPlugin;
import com.github.jengelman.gradle.plugins.shadow.tasks.ShadowJar;
import org.gradle.api.Plugin;
import org.gradle.api.Project;
import org.gradle.api.plugins.JavaLibraryPlugin;
import org.gradle.jvm.tasks.Jar;

import static java.util.Collections.singletonList;

public class RewriteShadowPlugin implements Plugin<Project> {

    @Override
    public void apply(Project project) {
        project.getPlugins().apply(JavaLibraryPlugin.class);
        project.getPlugins().apply(ShadowPlugin.class);

        project.getTasks().named("jar", Jar.class, task ->
                task.setEnabled(false));

        project.getTasks().withType(ShadowJar.class, task -> {
            task.getConfigurations().set(singletonList(project.getConfigurations().getByName("compileClasspath")));
            task.getArchiveClassifier().set((String) null);
        });
    }
}
